@@ -12,6 +12,7 @@
 
 #include <KLocalizedString>
 #include <KShell>
+#include <KTextEditor/Document>
 #include <KTextEditor/View>
 #include <QFileInfo>
 #include <QRegularExpression>
@@ -113,4 +114,6 @@ QString KateToolRunner::errorData() const
     return textFromLocal(m_stderr);
 }
 
+#include "moc_katetoolrunner.cpp"
+
 // kate: space-indent on; indent-width 4; replace-tabs on;
