@@ -9,7 +9,6 @@
 #include <limits>
 
 #include "dap/bus_selector.h"
-#include "dap/settings.h"
 #include "dapclient_debug.h"
 
 #include "messages.h"
@@ -18,14 +17,6 @@ namespace dap
 {
 constexpr int MAX_HEADER_SIZE = 1 << 16;
 
-template<typename T>
-inline Client::ResponseHandler make_response_handler(void (T::*member)(const Response &response, const QJsonValue &request), T *object)
-{
-    return [object, member](const Response &response, const QJsonValue &request) {
-        return (object->*member)(response, request);
-    };
-}
-
 Client::Client(const settings::ProtocolSettings &protocolSettings, Bus *bus, QObject *parent)
     : QObject(parent)
     , m_bus(bus)
@@ -104,6 +95,8 @@ void Client::processProtocolMessage(const QJsonObject &msg)
         processResponse(msg);
     } else if (DAP_EVENT == type) {
         processEvent(msg);
+    } else if (DAP_REQUEST == type) {
+        processReverseRequest(msg);
     } else {
         qCWarning(DAPCLIENT) << "unknown, empty or unexpected ProtocolMessage::" << DAP_TYPE << " (" << type << ")";
     }
@@ -134,8 +127,8 @@ void Client::processResponse(const QJsonObject &msg)
     const auto request = m_requests.take(response.request_seq);
 
     // check response
-    if (response.command != std::get<0>(request)) {
-        qCWarning(DAPCLIENT) << "unexpected command in response: " << response.command << " (expected: " << std::get<0>(request) << ")";
+    if (response.command != request.command) {
+        qCWarning(DAPCLIENT) << "unexpected command in response: " << response.command << " (expected: " << request.command << ")";
     }
     if (response.isCancelled()) {
         qCWarning(DAPCLIENT) << "request cancelled: " << response.command;
@@ -144,7 +137,17 @@ void Client::processResponse(const QJsonObject &msg)
     if (!response.success) {
         Q_EMIT errorResponse(response.message, response.errorBody);
     }
-    std::get<2>(request)(response, std::get<1>(request));
+    (this->*request.callback)(response, request.arguments);
+}
+
+void Client::processReverseRequest(const QJsonObject &msg)
+{
+    if (!msg.contains(DAP_SEQ) || msg[DAP_COMMAND].toString() != DAP_RUN_IN_TERMINAL) {
+        // error response
+        write(makeResponse(msg, false));
+        return;
+    }
+    processRequestRunInTerminal(msg);
 }
 
 void Client::processResponseInitialize(const Response &response, const QJsonValue &)
@@ -177,85 +180,35 @@ void Client::processEvent(const QJsonObject &msg)
     const auto body = msg[DAP_BODY].toObject();
 
     if (QStringLiteral("initialized") == event) {
-        processEventInitialized();
+        if ((m_state != State::Initializing)) {
+            qCWarning(DAPCLIENT) << "unexpected initialized event";
+            return;
+        }
+        setState(State::Initialized);
     } else if (QStringLiteral("terminated") == event) {
-        processEventTerminated();
+        Q_EMIT debuggeeTerminated(true);
     } else if (QStringLiteral("exited") == event) {
-        processEventExited(body);
+        const int exitCode = body[QStringLiteral("exitCode")].toInt(-1);
+        Q_EMIT debuggeeExited(exitCode);
     } else if (DAP_OUTPUT == event) {
-        processEventOutput(body);
+        Q_EMIT outputProduced(Output(body));
     } else if (QStringLiteral("process") == event) {
-        processEventProcess(body);
+        Q_EMIT debuggingProcess(ProcessInfo(body));
     } else if (QStringLiteral("thread") == event) {
-        processEventThread(body);
+        Q_EMIT threadChanged(ThreadEvent(body));
     } else if (QStringLiteral("stopped") == event) {
-        processEventStopped(body);
+        Q_EMIT debuggeeStopped(StoppedEvent(body));
     } else if (QStringLiteral("module") == event) {
-        processEventModule(body);
+        Q_EMIT moduleChanged(ModuleEvent(body));
     } else if (QStringLiteral("continued") == event) {
-        processEventContinued(body);
+        Q_EMIT debuggeeContinued(ContinuedEvent(body));
     } else if (DAP_BREAKPOINT == event) {
-        processEventBreakpoint(body);
+        Q_EMIT breakpointChanged(BreakpointEvent(body));
     } else {
         qCWarning(DAPCLIENT) << "unsupported event: " << event;
     }
 }
 
-void Client::processEventInitialized()
-{
-    if ((m_state != State::Initializing)) {
-        qCWarning(DAPCLIENT) << "unexpected initialized event";
-        return;
-    }
-    setState(State::Initialized);
-}
-
-void Client::processEventTerminated()
-{
-    setState(State::Terminated);
-}
-
-void Client::processEventExited(const QJsonObject &body)
-{
-    const int exitCode = body[QStringLiteral("exitCode")].toInt(-1);
-    Q_EMIT debuggeeExited(exitCode);
-}
-
-void Client::processEventOutput(const QJsonObject &body)
-{
-    Q_EMIT outputProduced(Output(body));
-}
-
-void Client::processEventProcess(const QJsonObject &body)
-{
-    Q_EMIT debuggingProcess(ProcessInfo(body));
-}
-
-void Client::processEventThread(const QJsonObject &body)
-{
-    Q_EMIT threadChanged(ThreadEvent(body));
-}
-
-void Client::processEventStopped(const QJsonObject &body)
-{
-    Q_EMIT debuggeeStopped(StoppedEvent(body));
-}
-
-void Client::processEventModule(const QJsonObject &body)
-{
-    Q_EMIT moduleChanged(ModuleEvent(body));
-}
-
-void Client::processEventContinued(const QJsonObject &body)
-{
-    Q_EMIT debuggeeContinued(ContinuedEvent(body));
-}
-
-void Client::processEventBreakpoint(const QJsonObject &body)
-{
-    Q_EMIT breakpointChanged(BreakpointEvent(body));
-}
-
 void Client::processResponseConfigurationDone(const Response &response, const QJsonValue &)
 {
     if (response.success) {
@@ -342,8 +295,9 @@ void Client::processResponsePause(const Response &, const QJsonValue &)
 {
 }
 
-void Client::processResponseTerminate(const Response &, const QJsonValue &)
+void Client::processResponseTerminate(const Response &r, const QJsonValue &)
 {
+    Q_EMIT debuggeeTerminated(r.success);
 }
 
 void Client::processResponseHotReload(const Response &, const QJsonValue &)
@@ -415,11 +369,30 @@ void Client::processResponseGotoTargets(const Response &response, const QJsonVal
     }
 }
 
+void Client::processRequestRunInTerminal(const QJsonObject &msg)
+{
+    Q_EMIT debuggeeRequiresTerminal(RunInTerminalRequestArguments(msg[DAP_ARGUMENTS].toObject()),
+                                    [this, msg](bool success, const std::optional<int> &processId, const std::optional<int> &terminalId) {
+                                        auto response = makeResponse(msg, success);
+                                        // Response
+                                        if (success) {
+                                            QJsonObject message;
+                                            if (processId) {
+                                                message[QStringLiteral("processId")] = *processId;
+                                            }
+                                            if (terminalId) {
+                                                message[QStringLiteral("shellProcessId")] = *terminalId;
+                                            }
+                                            response[DAP_BODY] = message;
+                                        }
+                                        this->write(response);
+                                    });
+}
+
 void Client::setState(const State &state)
 {
     if (state != m_state) {
         m_state = state;
-        Q_EMIT stateChanged(m_state);
 
         switch (m_state) {
         case State::Initialized:
@@ -429,9 +402,6 @@ void Client::setState(const State &state)
         case State::Running:
             Q_EMIT debuggeeRunning();
             break;
-        case State::Terminated:
-            Q_EMIT debuggeeTerminated();
-            break;
         case State::Failed:
             Q_EMIT failed();
             break;
@@ -468,7 +438,7 @@ void Client::write(const QJsonObject &msg)
  * command: str
  * arguments?: any
  */
-QJsonObject Client::makeRequest(const QString &command, const QJsonValue &arguments, const ResponseHandler &handler)
+QJsonObject Client::makeRequest(const QString &command, const QJsonValue &arguments, ResponseHandler handler)
 {
     const int seq = sequenceNumber();
     QJsonObject message;
@@ -480,11 +450,20 @@ QJsonObject Client::makeRequest(const QString &command, const QJsonValue &argume
     if (!arguments.isUndefined()) {
         message[DAP_ARGUMENTS] = arguments;
     }
-    m_requests[seq] = std::make_tuple(command, arguments, handler);
+    m_requests[seq] = Request{command, arguments, handler};
 
     return message;
 }
 
+QJsonObject Client::makeResponse(const QJsonObject &request, bool success)
+{
+    return QJsonObject{{DAP_SEQ, sequenceNumber()},
+                       {DAP_TYPE, DAP_RESPONSE},
+                       {DAP_REQUEST_SEQ, request[DAP_SEQ].toInt(-1)},
+                       {DAP_COMMAND, request[DAP_COMMAND]},
+                       {DAP_SUCCESS, success}};
+}
+
 void Client::requestInitialize()
 {
     const QJsonObject capabilities{// TODO clientID?: string
@@ -496,14 +475,14 @@ void Client::requestInitialize()
                                    {DAP_PATH, (m_protocol.pathFormatURI ? DAP_URI : DAP_PATH)},
                                    {DAP_SUPPORTS_VARIABLE_TYPE, true},
                                    {DAP_SUPPORTS_VARIABLE_PAGING, false},
-                                   {DAP_SUPPORTS_RUN_IN_TERMINAL_REQUEST, false},
+                                   {DAP_SUPPORTS_RUN_IN_TERMINAL_REQUEST, m_protocol.runInTerminal},
                                    {DAP_SUPPORTS_MEMORY_REFERENCES, false},
                                    {DAP_SUPPORTS_PROGRESS_REPORTING, false},
                                    {DAP_SUPPORTS_INVALIDATED_EVENT, false},
                                    {DAP_SUPPORTS_MEMORY_EVENT, false}};
 
     setState(State::Initializing);
-    this->write(makeRequest(DAP_INITIALIZE, capabilities, make_response_handler(&Client::processResponseInitialize, this)));
+    this->write(makeRequest(DAP_INITIALIZE, capabilities, &Client::processResponseInitialize));
 }
 
 void Client::requestConfigurationDone()
@@ -518,26 +497,26 @@ void Client::requestConfigurationDone()
         return;
     }
 
-    this->write(makeRequest(QStringLiteral("configurationDone"), QJsonObject{}, make_response_handler(&Client::processResponseConfigurationDone, this)));
+    this->write(makeRequest(QStringLiteral("configurationDone"), QJsonObject{}, &Client::processResponseConfigurationDone));
 }
 
 void Client::requestThreads()
 {
-    this->write(makeRequest(DAP_THREADS, QJsonObject{}, make_response_handler(&Client::processResponseThreads, this)));
+    this->write(makeRequest(DAP_THREADS, QJsonObject{}, &Client::processResponseThreads));
 }
 
 void Client::requestStackTrace(int threadId, int startFrame, int levels)
 {
     const QJsonObject arguments{{DAP_THREAD_ID, threadId}, {QStringLiteral("startFrame"), startFrame}, {QStringLiteral("levels"), levels}};
 
-    this->write(makeRequest(QStringLiteral("stackTrace"), arguments, make_response_handler(&Client::processResponseStackTrace, this)));
+    this->write(makeRequest(QStringLiteral("stackTrace"), arguments, &Client::processResponseStackTrace));
 }
 
 void Client::requestScopes(int frameId)
 {
     const QJsonObject arguments{{DAP_FRAME_ID, frameId}};
 
-    this->write(makeRequest(DAP_SCOPES, arguments, make_response_handler(&Client::processResponseScopes, this)));
+    this->write(makeRequest(DAP_SCOPES, arguments, &Client::processResponseScopes));
 }
 
 void Client::requestVariables(int variablesReference, Variable::Type filter, int start, int count)
@@ -558,12 +537,12 @@ void Client::requestVariables(int variablesReference, Variable::Type filter, int
     default:;
     }
 
-    this->write(makeRequest(DAP_VARIABLES, arguments, make_response_handler(&Client::processResponseVariables, this)));
+    this->write(makeRequest(DAP_VARIABLES, arguments, &Client::processResponseVariables));
 }
 
 void Client::requestModules(int start, int count)
 {
-    this->write(makeRequest(DAP_MODULES, QJsonObject{{DAP_START, start}, {DAP_COUNT, count}}, make_response_handler(&Client::processResponseModules, this)));
+    this->write(makeRequest(DAP_MODULES, QJsonObject{{DAP_START, start}, {DAP_COUNT, count}}, &Client::processResponseModules));
 }
 
 void Client::requestNext(int threadId, bool singleThread)
@@ -572,7 +551,7 @@ void Client::requestNext(int threadId, bool singleThread)
     if (singleThread) {
         arguments[DAP_SINGLE_THREAD] = true;
     }
-    this->write(makeRequest(QStringLiteral("next"), arguments, make_response_handler(&Client::processResponseNext, this)));
+    this->write(makeRequest(QStringLiteral("next"), arguments, &Client::processResponseNext));
 }
 
 void Client::requestStepIn(int threadId, bool singleThread)
@@ -581,7 +560,7 @@ void Client::requestStepIn(int threadId, bool singleThread)
     if (singleThread) {
         arguments[DAP_SINGLE_THREAD] = true;
     }
-    this->write(makeRequest(QStringLiteral("stepIn"), arguments, make_response_handler(&Client::processResponseNext, this)));
+    this->write(makeRequest(QStringLiteral("stepIn"), arguments, &Client::processResponseNext));
 }
 
 void Client::requestStepOut(int threadId, bool singleThread)
@@ -590,14 +569,14 @@ void Client::requestStepOut(int threadId, bool singleThread)
     if (singleThread) {
         arguments[DAP_SINGLE_THREAD] = true;
     }
-    this->write(makeRequest(QStringLiteral("stepOut"), arguments, make_response_handler(&Client::processResponseNext, this)));
+    this->write(makeRequest(QStringLiteral("stepOut"), arguments, &Client::processResponseNext));
 }
 
 void Client::requestGoto(int threadId, int targetId)
 {
     const QJsonObject arguments{{DAP_THREAD_ID, threadId}, {DAP_TARGET_ID, targetId}};
 
-    this->write(makeRequest(QStringLiteral("goto"), arguments, make_response_handler(&Client::processResponseNext, this)));
+    this->write(makeRequest(QStringLiteral("goto"), arguments, &Client::processResponseNext));
 }
 
 void Client::requestContinue(int threadId, bool singleThread)
@@ -606,14 +585,14 @@ void Client::requestContinue(int threadId, bool singleThread)
     if (singleThread) {
         arguments[DAP_SINGLE_THREAD] = true;
     }
-    this->write(makeRequest(QStringLiteral("continue"), arguments, make_response_handler(&Client::processResponseContinue, this)));
+    this->write(makeRequest(QStringLiteral("continue"), arguments, &Client::processResponseContinue));
 }
 
 void Client::requestPause(int threadId)
 {
     const QJsonObject arguments{{DAP_THREAD_ID, threadId}};
 
-    this->write(makeRequest(QStringLiteral("pause"), arguments, make_response_handler(&Client::processResponsePause, this)));
+    this->write(makeRequest(QStringLiteral("pause"), arguments, &Client::processResponsePause));
 }
 
 void Client::requestTerminate(bool restart)
@@ -623,7 +602,7 @@ void Client::requestTerminate(bool restart)
         arguments[QStringLiteral("restart")] = true;
     }
 
-    this->write(makeRequest(QStringLiteral("terminate"), arguments, make_response_handler(&Client::processResponseTerminate, this)));
+    this->write(makeRequest(QStringLiteral("terminate"), arguments, &Client::processResponseTerminate));
 }
 
 void Client::requestDisconnect(bool restart)
@@ -633,7 +612,7 @@ void Client::requestDisconnect(bool restart)
         arguments[QStringLiteral("restart")] = true;
     }
 
-    this->write(makeRequest(QStringLiteral("disconnect"), arguments, make_response_handler(&Client::processResponseDisconnect, this)));
+    this->write(makeRequest(QStringLiteral("disconnect"), arguments, &Client::processResponseDisconnect));
 }
 
 void Client::requestSource(const Source &source)
@@ -643,15 +622,15 @@ void Client::requestSource(const Source &source)
 
     arguments[DAP_SOURCE] = sourceArg;
 
-    this->write(makeRequest(DAP_SOURCE, arguments, make_response_handler(&Client::processResponseSource, this)));
+    this->write(makeRequest(DAP_SOURCE, arguments, &Client::processResponseSource));
 }
 
-void Client::requestSetBreakpoints(const QString &path, const QList<SourceBreakpoint> breakpoints, bool sourceModified)
+void Client::requestSetBreakpoints(const QString &path, const QList<SourceBreakpoint> &breakpoints, bool sourceModified)
 {
     requestSetBreakpoints(Source(path), breakpoints, sourceModified);
 }
 
-void Client::requestSetBreakpoints(const Source &source, const QList<SourceBreakpoint> breakpoints, bool sourceModified)
+void Client::requestSetBreakpoints(const Source &source, const QList<SourceBreakpoint> &breakpoints, bool sourceModified)
 {
     QJsonArray bpoints;
     for (const auto &item : breakpoints) {
@@ -659,7 +638,7 @@ void Client::requestSetBreakpoints(const Source &source, const QList<SourceBreak
     }
     QJsonObject arguments{{DAP_SOURCE, source.toJson()}, {DAP_BREAKPOINTS, bpoints}, {QStringLiteral("sourceModified"), sourceModified}};
 
-    this->write(makeRequest(QStringLiteral("setBreakpoints"), arguments, make_response_handler(&Client::processResponseSetBreakpoints, this)));
+    this->write(makeRequest(QStringLiteral("setBreakpoints"), arguments, &Client::processResponseSetBreakpoints));
 }
 
 void Client::requestEvaluate(const QString &expression, const QString &context, std::optional<int> frameId)
@@ -672,7 +651,7 @@ void Client::requestEvaluate(const QString &expression, const QString &context,
         arguments[DAP_FRAME_ID] = *frameId;
     }
 
-    this->write(makeRequest(QStringLiteral("evaluate"), arguments, make_response_handler(&Client::processResponseEvaluate, this)));
+    this->write(makeRequest(QStringLiteral("evaluate"), arguments, &Client::processResponseEvaluate));
 }
 
 void Client::requestWatch(const QString &expression, std::optional<int> frameId)
@@ -692,7 +671,7 @@ void Client::requestGotoTargets(const Source &source, const int line, const std:
         arguments[DAP_COLUMN] = *column;
     }
 
-    this->write(makeRequest(QStringLiteral("gotoTargets"), arguments, make_response_handler(&Client::processResponseGotoTargets, this)));
+    this->write(makeRequest(QStringLiteral("gotoTargets"), arguments, &Client::processResponseGotoTargets));
 }
 
 void Client::requestLaunchCommand()
@@ -704,17 +683,17 @@ void Client::requestLaunchCommand()
     if (m_launchCommand.isNull() || m_launchCommand.isEmpty())
         return;
 
-    this->write(makeRequest(m_launchCommand, m_protocol.launchRequest, make_response_handler(&Client::processResponseLaunch, this)));
+    this->write(makeRequest(m_launchCommand, m_protocol.launchRequest, &Client::processResponseLaunch));
 }
 
 void Client::requestHotReload()
 {
-    this->write(makeRequest(QStringLiteral("hotReload"), {}, make_response_handler(&Client::processResponseHotReload, this)));
+    this->write(makeRequest(QStringLiteral("hotReload"), {}, &Client::processResponseHotReload));
 }
 
 void Client::requestHotRestart()
 {
-    this->write(makeRequest(QStringLiteral("hotRestart"), {}, make_response_handler(&Client::processResponseHotReload, this)));
+    this->write(makeRequest(QStringLiteral("hotRestart"), {}, &Client::processResponseHotReload));
 }
 
 void Client::checkRunning()
