@@ -14,7 +14,7 @@ SchemaBrowserWidget::SchemaBrowserWidget(QWidget *parent, SQLManager *manager)
     : QWidget(parent)
     , m_schemaWidget(new SchemaWidget(this, manager))
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_schemaWidget);
     setLayout(layout);
