@@ -272,7 +272,7 @@ public:
             return index.row();
         } else if (role == KTextEditor::CodeCompletionModel::IsExpandable) {
             return !match.documentation.value.isEmpty();
-        } else if (role == KTextEditor::CodeCompletionModel::ExpandingWidget && !match.documentation.value.isEmpty()) {
+        } else if (role == KTextEditor::CodeCompletionModel::ExpandingWidget) {
             if (m_server->capabilities().completionProvider.resolveProvider && !match.m_docResolved && !match.data.isNull()) {
                 QPersistentModelIndex pIndex = QPersistentModelIndex(index);
                 auto h = [this, pIndex](const LSPCompletionItem &c) {
@@ -281,6 +281,7 @@ public:
                         auto i = QModelIndex(pIndex);
                         // we only support resolving additionalTextEdits and documentation so only
                         // update those fields
+                        self->m_matches[i.row()].documentation.kind = c.documentation.kind;
                         self->m_matches[i.row()].documentation.value += c.documentation.value;
                         self->m_matches[i.row()].additionalTextEdits = c.additionalTextEdits;
                         self->m_matches[i.row()].m_docResolved = true;
