@@ -15,7 +15,6 @@
 #include <KLocalizedString>
 #include <KParts/ReadOnlyPart>
 #include <KPluginFactory>
-#include <kparts_version.h>
 
 #include <KParts/NavigationExtension>
 
@@ -254,5 +253,3 @@ bool KPartView::eventFilter(QObject *object, QEvent *event)
 
     return QObject::eventFilter(object, event);
 }
-
-#include "moc_kpartview.cpp"
