@@ -13,7 +13,9 @@
 #include "cppcheck.h"
 #include "eslint.h"
 #include "flake8.h"
+#include "ruff.h"
 #include "shellcheck.h"
+#include "tidy.h"
 
 QStandardItemModel *KateProjectCodeAnalysisSelector::model(QObject *parent)
 {
@@ -27,6 +29,8 @@ QStandardItemModel *KateProjectCodeAnalysisSelector::model(QObject *parent)
         new KateProjectCodeAnalysisToolCppcheck(model),
         // flake8, for Python
         new KateProjectCodeAnalysisToolFlake8(model),
+        // ruff (python)
+        new RuffTool(model),
         // ShellCheck, for sh/bash scripts
         new KateProjectCodeAnalysisToolShellcheck(model),
         // clazy for Qt C++
@@ -37,6 +41,8 @@ QStandardItemModel *KateProjectCodeAnalysisSelector::model(QObject *parent)
         new ESLint(model),
         // clippy
         new Clippy(model),
+        // html tidy
+        new HtmlTidyTool(model),
     };
 
     QList<QStandardItem *> column;
