@@ -345,19 +345,19 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Quick Fix"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("quickopen")));
-    ac->setDefaultShortcut(a, QKeySequence((Qt::CTRL | Qt::Key_Period)));
+    KActionCollection::setDefaultShortcut(a, QKeySequence((Qt::CTRL | Qt::Key_Period)));
 
     a = ac->addAction(QStringLiteral("goto_next_diagnostic"), this, &DiagnosticsView::nextItem);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Next Item"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
-    ac->setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_Right);
+    KActionCollection::setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_Right);
 
     a = ac->addAction(QStringLiteral("goto_prev_diagnostic"), this, &DiagnosticsView::previousItem);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Previous Item"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
-    ac->setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_Left);
+    KActionCollection::setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_Left);
 
     a = ac->addAction(QStringLiteral("diagnostics_clear_filter"), this, [this]() {
         DiagnosticsView::filterViewTo(nullptr);
@@ -365,7 +365,7 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Clear Diagnostics Filter"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-all")));
-    ac->setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_C);
+    KActionCollection::setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_C);
 
     a = ac->addAction(QStringLiteral("diagnostics_show_hover"), this, [this]() {
         if (auto v = m_mainWindow->activeView()) {
@@ -450,7 +450,10 @@ DiagnosticsView::~DiagnosticsView()
     }
     Q_ASSERT(m_providers.empty());
 
-    m_mainWindow->guiFactory()->removeClient(this);
+    // KDevelop's main window is destroyed before plugins are unloaded
+    if (m_mainWindow) {
+        m_mainWindow->guiFactory()->removeClient(this);
+    }
 }
 
 void DiagnosticsView::setupDiagnosticViewToolbar(QVBoxLayout *mainLayout)
@@ -505,12 +508,13 @@ void DiagnosticsView::setupDiagnosticViewToolbar(QVBoxLayout *mainLayout)
     });
 
     l->addWidget(m_filterLineEdit);
-    m_filterLineEdit->setPlaceholderText(i18n("Filter..."));
+    m_filterLineEdit->setPlaceholderText(i18n("Filter…"));
     m_filterLineEdit->setClearButtonEnabled(true);
     connect(m_filterLineEdit, &QLineEdit::textChanged, m_filterChangedTimer, [this] {
         m_filterChangedTimer->start();
     });
 
+    m_clearButton->setToolTip(i18nc("@info:tooltip", "Clear diagnostics"));
     m_clearButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-all")));
     connect(m_clearButton, &QToolButton::clicked, this, [this] {
         std::vector<KTextEditor::Document *> docs(m_diagnosticsMarks.begin(), m_diagnosticsMarks.end());
@@ -572,10 +576,13 @@ void DiagnosticsView::unregisterDiagnosticsProvider(DiagnosticsProvider *provide
     disconnect(provider, &DiagnosticsProvider::requestClearSuppressions, this, &DiagnosticsView::clearSuppressionsFromProvider);
     m_providers.erase(it);
 
-    m_providerModel->update(m_providers);
+    // save some work during shutdown
+    if (!m_inShutdown) {
+        m_providerModel->update(m_providers);
 
-    // clear diagnostics
-    clearDiagnosticsFromProvider(provider);
+        // clear diagnostics
+        clearDiagnosticsFromProvider(provider);
+    }
 }
 
 void DiagnosticsView::readSessionConfig(const KConfigGroup &config)
@@ -622,7 +629,7 @@ static DocumentDiagnosticItem *getItem(const QStandardItemModel &model, const QU
 {
     // local file in custom role, Qt::DisplayRole might have additional elements
     auto l = model.match(model.index(0, 0, QModelIndex()), Qt::UserRole, url.toString(QUrl::PreferLocalFile | QUrl::RemovePassword), 1, Qt::MatchExactly);
-    if (l.length()) {
+    if (!l.empty()) {
         return static_cast<DocumentDiagnosticItem *>(model.itemFromIndex(l.at(0)));
     }
     return nullptr;
@@ -648,7 +655,7 @@ static QStandardItem *getItem(const QStandardItem *topItem, KTextEditor::Cursor
             int first = 0, last = count - 1;
             int target = pos.line();
             while (first + 1 < last) {
-                int middle = first + (last - first) / 2;
+                int middle = first + ((last - first) / 2);
                 Q_ASSERT(first != middle);
                 Q_ASSERT(middle != last);
                 if (getLine(middle) < target) {
@@ -895,7 +902,7 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
         // rendering of lines with embedded newlines does not work so well
         // so ... split message by lines
         auto lines = diag.message.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-        item->setText(source + (lines.size() > 0 ? lines[0] : QString()));
+        item->setText(source + (!lines.empty() ? lines[0] : QString()));
         fillItemRoles(item, diagnostics.uri, diag.range, diag.severity);
         item->setData(QVariant::fromValue(provider), DiagnosticModelRole::ProviderRole);
         // add subsequent lines to subitems
@@ -1055,14 +1062,15 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc, QStandardItem *item)
         return;
     }
 
-    auto url = item->data(DiagnosticModelRole::FileUrlRole).toUrl();
+    const auto url = item->data(DiagnosticModelRole::FileUrlRole).toUrl().toDisplayString(QUrl::PreferLocalFile | QUrl::PrettyDecoded | QUrl::RemovePassword);
+    const auto docUrl = doc->url().toDisplayString(QUrl::PreferLocalFile | QUrl::PrettyDecoded | QUrl::RemovePassword);
     // document url could end up empty while in intermediate reload state
     // (and then it might match a parent item with no RangeData at all)
-    if (url != doc->url() || url.isEmpty()) {
+    if (url != docUrl || url.isEmpty()) {
         return;
     }
 
-    const KTextEditor::Range range = item->data(DiagnosticModelRole::RangeRole).value<KTextEditor::Range>();
+    const auto range = item->data(DiagnosticModelRole::RangeRole).value<KTextEditor::Range>();
     if (!range.isValid()) {
         return;
     }
@@ -1161,7 +1169,9 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc, QStandardItem *item)
     // ensure runtime match
     using Doc = KTextEditor::Document;
     connect(doc, &Doc::aboutToInvalidateMovingInterfaceContent, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
+#if KTEXTEDITOR_VERSION < QT_VERSION_CHECK(6, 9, 0)
     connect(doc, &Doc::aboutToDeleteMovingInterfaceContent, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
+#endif
     // reload might save/restore marks before/after above signals, so let's clear before that
     connect(doc, &Doc::aboutToReload, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
     connect(doc, &Doc::markClicked, this, &DiagnosticsView::onMarkClicked, Qt::UniqueConnection);
