@@ -431,7 +431,8 @@ bool KateApp::init()
     // the session will only get saved if Kate is properly closed and not if it gets killed.
     // Do it delayed, don't block the startup
     QTimer::singleShot(100, this, [this] {
-        sessionManager()->saveActiveSession(true);
+        qCDebug(LOG_KATE, "KateApp::init() save session on startup");
+        sessionManager()->saveActiveSession(true, /*isAutoSave=*/true);
     });
 
     return true;
@@ -562,6 +563,7 @@ void KateApp::shutdownKate(KateMainWindow *win)
         return;
     }
 
+    qCDebug(LOG_KATE, "KateApp::%s save session", __func__);
     sessionManager()->saveActiveSession(true);
 
     /**
